@@ -242,7 +242,7 @@ def extract_series_templ(meta, saveto, raw, download, cuda, trt):
     item_name = select_item[0].strip()
     if item_name == "" or item_name == "." or item_name == ".." or item_name.find("/") != -1:
         print(f"Invalid series templ name [{item_name}]")
-        return
+        return 1
 
     templ_name = f"{series_name}-{item_name}"
     templ_url = f"{trtpy.pypi_base_url}/code_template/{templ_name}.zip"
@@ -275,7 +275,7 @@ def extract_series_templ(meta, saveto, raw, download, cuda, trt):
     print(f"Done! current template is {templ_name}, {select_item[1]}")
     return 0
 
-def do_get_series(args):
+def do_get_series_single(args):
     if args.saveto is None:
         args.saveto = args.name
 
@@ -314,6 +314,56 @@ def do_get_series(args):
 
     return extract_series_templ(meta, args.saveto, args.raw, args.download, args.cuda, args.trt)
 
+def do_get_series_all(args):
+    if args.saveto is None:
+        args.saveto = args.name
+
+    if os.path.isdir(args.saveto):
+        while True:
+            opt = input(f"{args.saveto} has exists, overwrite? (Y=yes, N=no): default [Y]:").lower()
+            if opt == "": opt = "y"
+            if opt != "y" and opt != "n":
+                continue
+                
+            if opt == "n":
+                print("Operation cancel.")
+                return 0
+            break
+
+    if os.path.isfile(args.saveto):
+        print(f"{args.saveto} is file")
+        return 1
+
+    meta_url = f"{trtpy.pypi_base_url}/code_template/{args.name}.series.json"
+    meta_cache_local_file = os.path.join(downloader.CACHE_ROOT, "code_template", f"{args.name}.series.json")
+    if not args.download and os.path.exists(meta_cache_local_file):
+        print(f"Use cache {meta_cache_local_file}")
+    elif not downloader.download_to_file(meta_url, meta_cache_local_file):
+        print(f"Series '{args.name}' not found")
+        return 1
+
+    meta = json.load(open(meta_cache_local_file, "r", encoding="utf-8"))
+    templ_list = meta["list-templ"]
+
+    if len(templ_list) == 0:
+        print(f"Series list-templ is empty")
+        return 1
+
+    for index, (templ_name, templ_descript) in enumerate(templ_list):
+        new_save_to = f"{args.saveto}/{templ_name}"
+        current_index = 0
+        meta["current-index"] = index
+        success = extract_series_templ(meta, new_save_to, args.raw, args.download, args.cuda, args.trt)
+        if success != 0:
+            print(f"Download {templ_name} failed")
+            return 1
+    return 0
+
+def do_get_series_entity(args):
+    if args.single:
+        do_get_series_single(args)
+    else:
+        do_get_series_all(args)
 
 def do_change_proj(args):
 
@@ -370,7 +420,7 @@ def do_change_proj(args):
         
     if args.index != "":
         print(f"Unknow index [{args.index}]")
-    return 1
+    return 0
 
 
 def do_templ_list(args):
@@ -479,7 +529,7 @@ def do_series_detail(args):
     if print_current:
         current_item = templ_list[current_index]
         print(f"Current is {current_item[0]}, {current_item[1]}")
-    return 1
+    return 0
 
 def do_series_list(args):
 
@@ -701,6 +751,7 @@ if __name__ == "__main__":
     p.add_argument("saveto", type=str, help="save to directory, default[template name]", nargs="?")
     p.add_argument("--raw", action="store_true", help="do not replace variables")
     p.add_argument("--download", action="store_true", help="ignore cache and download template")
+    p.add_argument("--single", action="store_true", help="download single template")
 
     p = new_parser_with_version("change-proj", help="change series proj")
     p.add_argument("index", type=str, default="", help="series proj index, 1.1/cuinit", nargs="?")
@@ -753,7 +804,7 @@ if __name__ == "__main__":
         "tryload":       do_tryload,
         "env-source":    do_env_source,
         "inv-vars":      do_invert_variable,
-        "get-series":    do_get_series,
+        "get-series":    do_get_series_entity,
         "list-series":   do_series_list,
         "search-series": do_series_search,
         "change-proj":   do_change_proj,
