@@ -212,7 +212,7 @@ def update_graph(model, file, save, phase, method="part"):
         return
 
     proto = phase_map[phase]()
-    with open(file, "r") as f:
+    with open(file, "r", encoding="utf-8") as f:
         text_format.Parse(f.read(), proto)
 
     if phase == "graph":
