@@ -49,4 +49,4 @@ def process_code_template(proj_dir, namelist, variable_template, filter_func=fil
             new_content, found_variable = filter_func(content, variable_template)
             if found_variable:
                 print(f"Process variables {full_path}")
-                open(full_path, "w").write(new_content)
+                open(full_path, "w", encoding="utf-8").write(new_content)
